# HAllA History #

## v0.8.20 2021-09-29 ##

* Resolved dependencies requirements version in setup

## v0.8.19 2021-07-18 ##

* Resolved dependencies installation errors during setup

## v0.8.18 2020-08-26 ##

* Version synced with PyPi

## v0.0.7 2020-08-26 ##

* Add hallagram and hallanostic scripts
* Simplify installation to two steps

## v0.0.6 2020-08-24 ##

* Add more discretization methods: quantile, uniform, kmeans, jenks
* Enable data transformation: zscore, quantile, rank
* Fix diagnostic plots when NaNs exist
* Enable tuning similarity-to-distance function
* Update default configuration values

## v0.0.5 2020-08-11 ##

* Beautify clustermap and hallagram to avoid having to customize
* Enable running on console

## v0.0.4 2020-08-11 ##

* Enhance clustermap and hallagram - make parameters more consistent
* Enable tuning FDR method

## v0.0.3 2020-08-10 ##

* Enhance clustermap - add more parameters (mask, x_label, y_label, etc)
* Fix diagnostic plot - scatterplot axes

## v0.0.2 2020-08-10 ##

* Implement logging - can be turned off using `verbose` parameter

## v0.0.1 2020-08-07 ##

* Add initial workflows and examples